from copulae.archimedean import *
from copulae.elliptical import *
from copulae.empirical import *
from copulae.indep import *

__version__ = "0.5.1"


def doc():
    import webbrowser
    webbrowser.open('https://copulae.readthedocs.io/en/latest')
